/*
 * spl_info.c - Gives info about a spl file.
 * 
 * Copyright (c) 2004 by Fabian Franz.
 *
 * License: GPL
 *
 */

#include "spl.h"
#include <stdio.h>

SPLMETAHEADER header;
char* jobtitle=NULL;
int data1_size;
#define BUF_SIZE 65535
char buf[BUF_SIZE];

SMREMFFILE smremffile;
SMRDATASIZE smrdatasize;

int main(int argc, char** argv)
{
	FILE *fp, *fp_in;
	char* jobtitle;
	char null;
	int i=0;
	DWORD nSize=0;
		
	long seek_pos;

	if (argc < 4)
	{
		printf("Syntax: %s <out-file> <jobtitle> <page1.emf> [ <page2.emf> ... ]\n",argv[0]);
		return 1;
	}
	
	fp = fopen(argv[1],"w");
	if (fp==NULL)
	{
		printf("Error: Cannot write to %s.\n",argv[1]);
		return 2;
	}

	// Write "dummy" header record
	
	fwrite(&header, sizeof(header), 1, fp);
	
	jobtitle=argv[2];
	nSize=0;
	null='\0';
	while (jobtitle[0]!='\0')
	{
		fwrite(jobtitle,sizeof(char),1,fp);
		fwrite(&null,sizeof(char),1,fp);
		jobtitle++;
		nSize+=2*sizeof(char);
	}
	fwrite(&null,sizeof(char),1,fp);
	fwrite(&null,sizeof(char),1,fp);
	nSize+=2*sizeof(char);

	//Write real header record
		
	fseek(fp, 0, SEEK_SET);
	header.SIGNATURE=SPLMETA_SIGNATURE;
	header.nSize=nSize+sizeof(header);  
	header.unknown1=sizeof(header);   // sizeof previous data (0) + 
	                                 //   sizeof(header)=16
	header.unknown2=0; // Always 0, dunno why
	fwrite(&header, sizeof(header), 1, fp);

	// Go back to end
	fseek(fp, 0, SEEK_END);
	
	i=3;
	while (i < argc)
	{
		fp_in=fopen(argv[i],"r");

		if (fp_in==NULL)
			break;
		
		// Save current position
		seek_pos=ftell(fp);

		// Write "dummy" emffile record
		fwrite(&smremffile, sizeof(smremffile), 1, fp);

		nSize=0;
		while (!feof(fp_in))
		{
			int erg=fread(&buf, sizeof(char), BUF_SIZE, fp_in);
			fwrite(&buf, sizeof(char), erg, fp);
			nSize+=erg;
		}
		
		fclose(fp_in);
				
		fseek(fp, seek_pos, SEEK_SET);
		
		// Now write the real emffile record
		smremffile.smr.iType=SPL_EMFFILE;
		smremffile.smr.nSize=nSize;
		
		fwrite(&smremffile, sizeof(smremffile), 1, fp);
		fseek(fp, 0, SEEK_END);
		
		smrdatasize.smr.iType=SPL_SMRDATASIZE;
		// length of following data (=just the following two header DWORDs)
		smrdatasize.smr.nSize=2*sizeof(DWORD);

		smrdatasize.nSize=nSize+sizeof(smremffile);
		smrdatasize.Unknown=0; // Always 0, dunno why
		
		fwrite(&smrdatasize, sizeof(smrdatasize), 1, fp);
		i++;
	}

	fclose(fp);
	
	return 0;
}
