/*
 * spl_info.c - Gives info about a spl file.
 * 
 * Copyright (c) 2004 by Fabian Franz.
 *
 * License: GPL
 *
 */

#include "spl.h"
#include <stdio.h>

SPLMETAHEADER header;
char* jobtitle=NULL;
int data1_size;

SMREMFFILE smremffile;
SMRDATASIZE smrdatasize;

void ausg_smr(SMR *psmr)
{
	printf("SMR:\n");
	printf("  iType: 0x%x\n", psmr->iType);
	printf("  nSize: %u\n", psmr->nSize);
}

void ausg_SPLMETAHEADER(void)
{
	int i=0;

	printf("SPLMETAHEADER\n\n");
	printf("SMR:\n");
	printf("  iType: 0x%x\n", header.SIGNATURE);
	printf("  nSize: %u\n", header.nSize);
	printf("nSize: %u\n", header.unknown1);
	printf("Unknown (0): %u\n", header.unknown2);

	printf("\nJobtitle: ");
	for (i=0; i< data1_size; i+=2)
	{
		printf("%c",jobtitle[i]);
	}
	printf("\n");
}

void ausg_SMREMFFILE(SMREMFFILE* psmremffile)
{
	printf("\nSPL_SMREMFFILE\n\n");
	ausg_smr(&(psmremffile->smr));
}

void ausg_SMRDATASIZE(SMRDATASIZE* psmrdatasize)
{
	printf("\nSPL_SMRDATASIZE\n\n");
	ausg_smr(&(psmrdatasize->smr));
	
	printf("nSize: %u\n", psmrdatasize->nSize);
	printf("Unknown (0): %u\n", psmrdatasize->Unknown);
}

int main(int argc, char** argv)
{
	FILE* fp;
	int erg=0;

	if (argc < 2)
	{
		printf("Syntax: %s <filename>\n",argv[0]);
		return 1;
	}
	
	fp = fopen(argv[1],"r");
	if (fp==NULL)
	{
		printf("Error: File %s not found.\n",argv[1]);
		return 2;
	}
	fread(&header, sizeof(header), 1, fp);

	if (header.SIGNATURE != SPLMETA_SIGNATURE)
	{
		printf("Error: Not a valid SPL file.\n");
		return 3;
	}
	
	data1_size=header.nSize-4*sizeof(DWORD);
	jobtitle=(char*)malloc(sizeof(CHAR)*data1_size);
	fread(jobtitle, data1_size, sizeof(CHAR), fp);
	
	ausg_SPLMETAHEADER();
	
	while (!feof(fp))
	{
		erg=fread(&smremffile, sizeof(smremffile), 1, fp);
		if (erg!=1)
			break;
		if (smremffile.smr.iType!=SPL_EMFFILE)
		{
			printf("Error: Type not SPL_EMFFILE (0x%x), Found: 0x%x\n", SPL_EMFFILE, smremffile.smr.iType);
			return 4;
		}
		ausg_SMREMFFILE(&smremffile);

		// If you need the emf-file read it in here, instead of skipping ...
		fseek(fp, smremffile.smr.nSize*sizeof(CHAR), SEEK_CUR);
		
		fread(&smrdatasize, sizeof(smrdatasize), 1, fp);

		ausg_SMRDATASIZE(&smrdatasize);
		
		if (smrdatasize.smr.iType==SPL_SMRDATASIZE_PAD)
		{
			printf("Found padded data: Exiting\n");
			break;
		}
			
	}
	
	free(jobtitle);
	fclose(fp);
	return 0;
}
